@@ -3,8 +3,8 @@
 // ProgressBars bindings
 Shiny.addCustomMessageHandler('update-progressBar-shinyWidgets', function(data) {
   var id = data.id;
-  var total = typeof data.total !== null ? data.total : -1;
-  var value = data.value;
+  var total = data.total;
+  var value = Math.round(data.value);
   //console.log(data.statusp);
   //var statusp = typeof data.statusp !== 'undefined' ? data.statusp : "none";
   var pct;
@@ -12,13 +12,14 @@ Shiny.addCustomMessageHandler('update-progressBar-shinyWidgets', function(data)
     pct = Math.round(value / total * 100);
     $('#' + id + '-value').text(value);
     $('#' + id + '-total').text(total);
+    value = Math.round(value / total * 100);
   } else {
-    pct = Math.round(value);
+    pct = data.percent > 0 ? data.percent : value;
   }
   $('#' + id).css('width', pct + '%');
   var txt = $('#' + id).text();
   if (txt !== "") { //value.display_pct !== undefined
-    $('#' + id).text(pct + '%');
+    $('#' + id).text(value + data.unit_mark);
   }
   if (data.status !== null) {
     $('#' + id).removeClass();
